@@ -16,12 +16,12 @@
  */
 
 #include "sysincludes.h"
-#include "msdos.h"
+#include "mtools.h"
 
-const char *mversion="4.0.36";
+const char *mversion="4.0.47";
 
 /* Multiple releases on same day should be marked with (b), (cd), (d) after
  * date string below */
-const char *mdate = "November 21st, 2021";
+const char *mdate = "November 21st, 2024";
 
-const char *mformat_banner = "MTOO4036";
+const char *mformat_banner = "MTOO4047";
